==> pipewire-docs-1%3A0.3.56-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/globals_dup.js <==
var globals_dup =
[
    [ "_", "globals.html", null ],
    [ "abs", "globals_a.html", null ],
    [ "align", "globals_a.html", null ],
    [ "ansi_", "globals_a.html", null ],
    [ "aprin", "globals_a.html", null ],
    [ "arra", "globals_a.html", null ],
    [ "asser", "globals_a.html", null ],
    [ "async", "globals_a.html", null ],
    [ "atob", "globals_a.html", null ],
    [ "atod", "globals_a.html", null ],
    [ "atof", "globals_a.html", null ],
    [ "atoi3", "globals_a.html", null ],
    [ "atoi6", "globals_a.html", null ],
    [ "atou3", "globals_a.html", null ],
    [ "atou6", "globals_a.html", null ],
    [ "audio", "globals_a.html", null ],
    [ "bluet", "globals_b.html", null ],
    [ "buff", "globals_b.html", null ],
    [ "buffe", "globals_b.html", null ],
    [ "callb", "globals_c.html", null ],
    [ "chec", "globals_c.html", null ],
    [ "choic", "globals_c.html", null ],
    [ "chunk", "globals_c.html", null ],
    [ "clamp", "globals_c.html", null ],
    [ "clie", "globals_c.html", null ],
    [ "comma", "globals_c.html", null ],
    [ "conf", "globals_c.html", null ],
    [ "cont", "globals_c.html", null ],
    [ "conta", "globals_c.html", null ],
    [ "contr", "globals_c.html", null ],
    [ "core", "globals_c.html", null ],
    [ "cpu_f", "globals_c.html", null ],
    [ "cpu_g", "globals_c.html", null ],
    [ "cpu_m", "globals_c.html", null ],
    [ "cpu_v", "globals_c.html", null ],
    [ "cpu_z", "globals_c.html", null ],
    [ "data", "globals_d.html", null ],
    [ "data_", "globals_d.html", null ],
    [ "dbus_", "globals_d.html", null ],
    [ "debu", "globals_d.html", null ],
    [ "debug", "globals_d.html", null ],
    [ "defa", "globals_d.html", null ],
    [ "dein", "globals_d.html", null ],
    [ "depre", "globals_d.html", null ],
    [ "dest", "globals_d.html", null ],
    [ "devi", "globals_d.html", null ],
    [ "devic", "globals_d.html", null ],
    [ "dict_", "globals_d.html", null ],
    [ "dire", "globals_d.html", null ],
    [ "direc", "globals_d.html", null ],
    [ "dtoa", "globals_d.html", null ],
    [ "endp", "globals_e.html", null ],
    [ "event", "globals_e.html", null ],
    [ "expor", "globals_e.html", null ],
    [ "exte", "globals_e.html", null ],
    [ "fact", "globals_f.html", null ],
    [ "fallt", "globals_f.html", null ],
    [ "fd_cl", "globals_f.html", null ],
    [ "fd_ev", "globals_f.html", null ],
    [ "fd_no", "globals_f.html", null ],
    [ "fd_ti", "globals_f.html", null ],
    [ "filt", "globals_f.html", null ],
    [ "flag_", "globals_f.html", null ],
    [ "for_e", "globals_f.html", null ],
    [ "forma", "globals_f.html", null ],
    [ "fract", "globals_f.html", null ],
    [ "free", "globals_f.html", null ],
    [ "get_", "globals_g.html", null ],
    [ "getr", "globals_g.html", null ],
    [ "glob", "globals_g.html", null ],
    [ "graph", "globals_g.html", null ],
    [ "h264_", "globals_h.html", null ],
    [ "handl", "globals_h.html", null ],
    [ "hook_", "globals_h.html", null ],
    [ "i18n_", "globals_i.html", null ],
    [ "id_a", "globals_i.html", null ],
    [ "id_c", "globals_i.html", null ],
    [ "id_in", "globals_i.html", null ],
    [ "idx_i", "globals_i.html", null ],
    [ "impl", "globals_i.html", null ],
    [ "in_v", "globals_i.html", null ],
    [ "init", "globals_i.html", null ],
    [ "int_t", "globals_i.html", null ],
    [ "inter", "globals_i.html", null ],
    [ "invok", "globals_i.html", null ],
    [ "io_bu", "globals_i.html", null ],
    [ "io_cl", "globals_i.html", null ],
    [ "io_co", "globals_i.html", null ],
    [ "io_er", "globals_i.html", null ],
    [ "io_hu", "globals_i.html", null ],
    [ "io_in", "globals_i.html", null ],
    [ "io_la", "globals_i.html", null ],
    [ "io_me", "globals_i.html", null ],
    [ "io_no", "globals_i.html", null ],
    [ "io_ou", "globals_i.html", null ],
    [ "io_po", "globals_i.html", null ],
    [ "io_ra", "globals_i.html", null ],
    [ "io_se", "globals_i.html", null ],
    [ "io_ty", "globals_i.html", null ],
    [ "io_vi", "globals_i.html", null ],
    [ "is_al", "globals_i.html", null ],
    [ "json_", "globals_j.html", null ],
    [ "key_", "globals_k.html", null ],
    [ "key_a", "globals_k.html", null ],
    [ "key_c", "globals_k.html", null ],
    [ "key_d", "globals_k.html", null ],
    [ "key_f", "globals_k.html", null ],
    [ "key_l", "globals_k.html", null ],
    [ "key_m", "globals_k.html", null ],
    [ "key_n", "globals_k.html", null ],
    [ "key_o", "globals_k.html", null ],
    [ "key_p", "globals_k.html", null ],
    [ "key_t", "globals_k.html", null ],
    [ "laten", "globals_l.html", null ],
    [ "likel", "globals_l.html", null ],
    [ "link", "globals_l.html", null ],
    [ "list_", "globals_l.html", null ],
    [ "load", "globals_l.html", null ],
    [ "log", "globals_l.html", null ],
    [ "log_", "globals_l.html", null ],
    [ "log_d", "globals_l.html", null ],
    [ "log_e", "globals_l.html", null ],
    [ "log_i", "globals_l.html", null ],
    [ "log_l", "globals_l.html", null ],
    [ "log_t", "globals_l.html", null ],
    [ "log_w", "globals_l.html", null ],
    [ "logt", "globals_l.html", null ],
    [ "logt_", "globals_l.html", null ],
    [ "loop", "globals_l.html", null ],
    [ "loop_", "globals_l.html", null ],
    [ "main", "globals_m.html", null ],
    [ "map_", "globals_m.html", null ],
    [ "max", "globals_m.html", null ],
    [ "media", "globals_m.html", null ],
    [ "memb", "globals_m.html", null ],
    [ "membe", "globals_m.html", null ],
    [ "memcp", "globals_m.html", null ],
    [ "memm", "globals_m.html", null ],
    [ "memmo", "globals_m.html", null ],
    [ "memp", "globals_m.html", null ],
    [ "memze", "globals_m.html", null ],
    [ "meta", "globals_m.html", null ],
    [ "meta_", "globals_m.html", null ],
    [ "min", "globals_m.html", null ],
    [ "modu", "globals_m.html", null ],
    [ "msec_", "globals_m.html", null ],
    [ "n", "globals_n.html", null ],
    [ "n_ele", "globals_n.html", null ],
    [ "name_", "globals_n.html", null ],
    [ "node", "globals_n.html", null ],
    [ "node_", "globals_n.html", null ],
    [ "nop", "globals_n.html", null ],
    [ "noret", "globals_n.html", null ],
    [ "nsec_", "globals_n.html", null ],
    [ "p", "globals_p.html", null ],
    [ "param", "globals_p.html", null ],
    [ "perm", "globals_p.html", null ],
    [ "plugi", "globals_p.html", null ],
    [ "pod_a", "globals_p.html", null ],
    [ "pod_b", "globals_p.html", null ],
    [ "pod_c", "globals_p.html", null ],
    [ "pod_d", "globals_p.html", null ],
    [ "pod_f", "globals_p.html", null ],
    [ "pod_g", "globals_p.html", null ],
    [ "pod_i", "globals_p.html", null ],
    [ "pod_l", "globals_p.html", null ],
    [ "pod_n", "globals_p.html", null ],
    [ "pod_o", "globals_p.html", null ],
    [ "pod_p", "globals_p.html", null ],
    [ "pod_r", "globals_p.html", null ],
    [ "pod_s", "globals_p.html", null ],
    [ "pod_t", "globals_p.html", null ],
    [ "pod_v", "globals_p.html", null ],
    [ "point", "globals_p.html", null ],
    [ "port", "globals_p.html", null ],
    [ "port_", "globals_p.html", null ],
    [ "print", "globals_p.html", null ],
    [ "proce", "globals_p.html", null ],
    [ "prof", "globals_p.html", null ],
    [ "profi", "globals_p.html", null ],
    [ "prop", "globals_p.html", null ],
    [ "prop_", "globals_p.html", null ],
    [ "prot", "globals_p.html", null ],
    [ "prox", "globals_p.html", null ],
    [ "ptr_a", "globals_p.html", null ],
    [ "ptr_t", "globals_p.html", null ],
    [ "ptrdi", "globals_p.html", null ],
    [ "ptrof", "globals_p.html", null ],
    [ "real", "globals_r.html", null ],
    [ "recta", "globals_r.html", null ],
    [ "regi", "globals_r.html", null ],
    [ "regio", "globals_r.html", null ],
    [ "reso", "globals_r.html", null ],
    [ "restr", "globals_r.html", null ],
    [ "resul", "globals_r.html", null ],
    [ "retur", "globals_r.html", null ],
    [ "ringb", "globals_r.html", null ],
    [ "round", "globals_r.html", null ],
    [ "s", "globals_s.html", null ],
    [ "scnpr", "globals_s.html", null ],
    [ "senti", "globals_s.html", null ],
    [ "sess", "globals_s.html", null ],
    [ "set_", "globals_s.html", null ],
    [ "sourc", "globals_s.html", null ],
    [ "spli", "globals_s.html", null ],
    [ "statu", "globals_s.html", null ],
    [ "stre", "globals_s.html", null ],
    [ "stren", "globals_s.html", null ],
    [ "streq", "globals_s.html", null ],
    [ "strer", "globals_s.html", null ],
    [ "stri", "globals_s.html", null ],
    [ "strin", "globals_s.html", null ],
    [ "strne", "globals_s.html", null ],
    [ "strst", "globals_s.html", null ],
    [ "strto", "globals_s.html", null ],
    [ "suppo", "globals_s.html", null ],
    [ "swap", "globals_s.html", null ],
    [ "syste", "globals_s.html", null ],
    [ "thre", "globals_t.html", null ],
    [ "threa", "globals_t.html", null ],
    [ "time_", "globals_t.html", null ],
    [ "times", "globals_t.html", null ],
    [ "timev", "globals_t.html", null ],
    [ "type", "globals_t.html", null ],
    [ "type_", "globals_t.html", null ],
    [ "typec", "globals_t.html", null ],
    [ "types", "globals_t.html", null ],
    [ "uint3", "globals_u.html", null ],
    [ "unlik", "globals_u.html", null ],
    [ "unlo", "globals_u.html", null ],
    [ "unuse", "globals_u.html", null ],
    [ "usec_", "globals_u.html", null ],
    [ "vers", "globals_v.html", null ],
    [ "versi", "globals_v.html", null ],
    [ "video", "globals_v.html", null ],
    [ "vscnp", "globals_v.html", null ],
    [ "work", "globals_w.html", null ],
    [ "zero", "globals_z.html", null ]
];

==> pipewire-docs-1%3A0.3.59-2-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/globals_dup.js <==
var globals_dup =
[
    [ "_", "globals.html", null ],
    [ "abs", "globals_a.html", null ],
    [ "align", "globals_a.html", null ],
    [ "ansi_", "globals_a.html", null ],
    [ "aprin", "globals_a.html", null ],
    [ "arra", "globals_a.html", null ],
    [ "asser", "globals_a.html", null ],
    [ "async", "globals_a.html", null ],
    [ "atob", "globals_a.html", null ],
    [ "atod", "globals_a.html", null ],
    [ "atof", "globals_a.html", null ],
    [ "atoi3", "globals_a.html", null ],
    [ "atoi6", "globals_a.html", null ],
    [ "atou3", "globals_a.html", null ],
    [ "atou6", "globals_a.html", null ],
    [ "audio", "globals_a.html", null ],
    [ "bluet", "globals_b.html", null ],
    [ "buff", "globals_b.html", null ],
    [ "buffe", "globals_b.html", null ],
    [ "callb", "globals_c.html", null ],
    [ "chec", "globals_c.html", null ],
    [ "choic", "globals_c.html", null ],
    [ "chunk", "globals_c.html", null ],
    [ "clamp", "globals_c.html", null ],
    [ "clie", "globals_c.html", null ],
    [ "comma", "globals_c.html", null ],
    [ "conf", "globals_c.html", null ],
    [ "cont", "globals_c.html", null ],
    [ "conta", "globals_c.html", null ],
    [ "contr", "globals_c.html", null ],
    [ "core", "globals_c.html", null ],
    [ "cpu_f", "globals_c.html", null ],
    [ "cpu_g", "globals_c.html", null ],
    [ "cpu_m", "globals_c.html", null ],
    [ "cpu_v", "globals_c.html", null ],
    [ "cpu_z", "globals_c.html", null ],
    [ "data", "globals_d.html", null ],
    [ "data_", "globals_d.html", null ],
    [ "dbus_", "globals_d.html", null ],
    [ "debu", "globals_d.html", null ],
    [ "debug", "globals_d.html", null ],
    [ "defa", "globals_d.html", null ],
    [ "dein", "globals_d.html", null ],
    [ "depre", "globals_d.html", null ],
    [ "dest", "globals_d.html", null ],
    [ "devi", "globals_d.html", null ],
    [ "devic", "globals_d.html", null ],
    [ "dict_", "globals_d.html", null ],
    [ "dire", "globals_d.html", null ],
    [ "direc", "globals_d.html", null ],
    [ "dtoa", "globals_d.html", null ],
    [ "endp", "globals_e.html", null ],
    [ "event", "globals_e.html", null ],
    [ "expor", "globals_e.html", null ],
    [ "exte", "globals_e.html", null ],
    [ "fact", "globals_f.html", null ],
    [ "fallt", "globals_f.html", null ],
    [ "fd_cl", "globals_f.html", null ],
    [ "fd_ev", "globals_f.html", null ],
    [ "fd_no", "globals_f.html", null ],
    [ "fd_ti", "globals_f.html", null ],
    [ "filt", "globals_f.html", null ],
    [ "flag_", "globals_f.html", null ],
    [ "for_e", "globals_f.html", null ],
    [ "forma", "globals_f.html", null ],
    [ "fract", "globals_f.html", null ],
    [ "free", "globals_f.html", null ],
    [ "get_", "globals_g.html", null ],
    [ "getr", "globals_g.html", null ],
    [ "glob", "globals_g.html", null ],
    [ "graph", "globals_g.html", null ],
    [ "h264_", "globals_h.html", null ],
    [ "handl", "globals_h.html", null ],
    [ "hook_", "globals_h.html", null ],
    [ "i18n_", "globals_i.html", null ],
    [ "id_a", "globals_i.html", null ],
    [ "id_c", "globals_i.html", null ],
    [ "id_in", "globals_i.html", null ],
    [ "idx_i", "globals_i.html", null ],
    [ "impl", "globals_i.html", null ],
    [ "in_v", "globals_i.html", null ],
    [ "init", "globals_i.html", null ],
    [ "int_t", "globals_i.html", null ],
    [ "inter", "globals_i.html", null ],
    [ "invok", "globals_i.html", null ],
    [ "io_bu", "globals_i.html", null ],
    [ "io_cl", "globals_i.html", null ],
    [ "io_co", "globals_i.html", null ],
    [ "io_er", "globals_i.html", null ],
    [ "io_hu", "globals_i.html", null ],
    [ "io_in", "globals_i.html", null ],
    [ "io_la", "globals_i.html", null ],
    [ "io_me", "globals_i.html", null ],
    [ "io_no", "globals_i.html", null ],
    [ "io_ou", "globals_i.html", null ],
    [ "io_po", "globals_i.html", null ],
    [ "io_ra", "globals_i.html", null ],
    [ "io_se", "globals_i.html", null ],
    [ "io_ty", "globals_i.html", null ],
    [ "io_vi", "globals_i.html", null ],
    [ "is_al", "globals_i.html", null ],
    [ "json_", "globals_j.html", null ],
    [ "key_", "globals_k.html", null ],
    [ "key_a", "globals_k.html", null ],
    [ "key_c", "globals_k.html", null ],
    [ "key_d", "globals_k.html", null ],
    [ "key_f", "globals_k.html", null ],
    [ "key_l", "globals_k.html", null ],
    [ "key_m", "globals_k.html", null ],
    [ "key_n", "globals_k.html", null ],
    [ "key_o", "globals_k.html", null ],
    [ "key_p", "globals_k.html", null ],
    [ "key_t", "globals_k.html", null ],
    [ "laten", "globals_l.html", null ],
    [ "likel", "globals_l.html", null ],
    [ "link", "globals_l.html", null ],
    [ "list_", "globals_l.html", null ],
    [ "load", "globals_l.html", null ],
    [ "log", "globals_l.html", null ],
    [ "log_", "globals_l.html", null ],
    [ "log_d", "globals_l.html", null ],
    [ "log_e", "globals_l.html", null ],
    [ "log_h", "globals_l.html", null ],
    [ "log_i", "globals_l.html", null ],
    [ "log_l", "globals_l.html", null ],
    [ "log_t", "globals_l.html", null ],
    [ "log_w", "globals_l.html", null ],
    [ "logt", "globals_l.html", null ],
    [ "logt_", "globals_l.html", null ],
    [ "loop", "globals_l.html", null ],
    [ "loop_", "globals_l.html", null ],
    [ "main", "globals_m.html", null ],
    [ "map_", "globals_m.html", null ],
    [ "mask_", "globals_m.html", null ],
    [ "max", "globals_m.html", null ],
    [ "media", "globals_m.html", null ],
    [ "memb", "globals_m.html", null ],
    [ "membe", "globals_m.html", null ],
    [ "memcp", "globals_m.html", null ],
    [ "memm", "globals_m.html", null ],
    [ "memmo", "globals_m.html", null ],
    [ "memp", "globals_m.html", null ],
    [ "memze", "globals_m.html", null ],
    [ "meta", "globals_m.html", null ],
    [ "meta_", "globals_m.html", null ],
    [ "min", "globals_m.html", null ],
    [ "modu", "globals_m.html", null ],
    [ "msec_", "globals_m.html", null ],
    [ "n", "globals_n.html", null ],
    [ "n_ele", "globals_n.html", null ],
    [ "name_", "globals_n.html", null ],
    [ "node", "globals_n.html", null ],
    [ "node_", "globals_n.html", null ],
    [ "nop", "globals_n.html", null ],
    [ "noret", "globals_n.html", null ],
    [ "nsec_", "globals_n.html", null ],
    [ "p", "globals_p.html", null ],
    [ "param", "globals_p.html", null ],
    [ "perm", "globals_p.html", null ],
    [ "plugi", "globals_p.html", null ],
    [ "pod_a", "globals_p.html", null ],
    [ "pod_b", "globals_p.html", null ],
    [ "pod_c", "globals_p.html", null ],
    [ "pod_d", "globals_p.html", null ],
    [ "pod_f", "globals_p.html", null ],
    [ "pod_g", "globals_p.html", null ],
    [ "pod_i", "globals_p.html", null ],
    [ "pod_l", "globals_p.html", null ],
    [ "pod_n", "globals_p.html", null ],
    [ "pod_o", "globals_p.html", null ],
    [ "pod_p", "globals_p.html", null ],
    [ "pod_r", "globals_p.html", null ],
    [ "pod_s", "globals_p.html", null ],
    [ "pod_t", "globals_p.html", null ],
    [ "pod_v", "globals_p.html", null ],
    [ "point", "globals_p.html", null ],
    [ "port", "globals_p.html", null ],
    [ "port_", "globals_p.html", null ],
    [ "print", "globals_p.html", null ],
    [ "proce", "globals_p.html", null ],
    [ "prof", "globals_p.html", null ],
    [ "profi", "globals_p.html", null ],
    [ "prop", "globals_p.html", null ],
    [ "prop_", "globals_p.html", null ],
    [ "prot", "globals_p.html", null ],
    [ "prox", "globals_p.html", null ],
    [ "ptr_a", "globals_p.html", null ],
    [ "ptr_t", "globals_p.html", null ],
    [ "ptrdi", "globals_p.html", null ],
    [ "ptrof", "globals_p.html", null ],
    [ "real", "globals_r.html", null ],
    [ "recta", "globals_r.html", null ],
    [ "regi", "globals_r.html", null ],
    [ "regio", "globals_r.html", null ],
    [ "reso", "globals_r.html", null ],
    [ "restr", "globals_r.html", null ],
    [ "resul", "globals_r.html", null ],
    [ "retur", "globals_r.html", null ],
    [ "ringb", "globals_r.html", null ],
    [ "round", "globals_r.html", null ],
    [ "s", "globals_s.html", null ],
    [ "scnpr", "globals_s.html", null ],
    [ "senti", "globals_s.html", null ],
    [ "sess", "globals_s.html", null ],
    [ "set_", "globals_s.html", null ],
    [ "sourc", "globals_s.html", null ],
    [ "spli", "globals_s.html", null ],
    [ "stati", "globals_s.html", null ],
    [ "statu", "globals_s.html", null ],
    [ "stre", "globals_s.html", null ],
    [ "stren", "globals_s.html", null ],
    [ "streq", "globals_s.html", null ],
    [ "strer", "globals_s.html", null ],
    [ "stri", "globals_s.html", null ],
    [ "strin", "globals_s.html", null ],
    [ "strne", "globals_s.html", null ],
    [ "strst", "globals_s.html", null ],
    [ "strto", "globals_s.html", null ],
    [ "suppo", "globals_s.html", null ],
    [ "swap", "globals_s.html", null ],
    [ "syste", "globals_s.html", null ],
    [ "thre", "globals_t.html", null ],
    [ "threa", "globals_t.html", null ],
    [ "time_", "globals_t.html", null ],
    [ "times", "globals_t.html", null ],
    [ "timev", "globals_t.html", null ],
    [ "type", "globals_t.html", null ],
    [ "type_", "globals_t.html", null ],
    [ "typec", "globals_t.html", null ],
    [ "types", "globals_t.html", null ],
    [ "uint3", "globals_u.html", null ],
    [ "unlik", "globals_u.html", null ],
    [ "unlo", "globals_u.html", null ],
    [ "unuse", "globals_u.html", null ],
    [ "usec_", "globals_u.html", null ],
    [ "vers", "globals_v.html", null ],
    [ "versi", "globals_v.html", null ],
    [ "video", "globals_v.html", null ],
    [ "vscnp", "globals_v.html", null ],
    [ "warn_", "globals_w.html", null ],
    [ "work", "globals_w.html", null ],
    [ "zero", "globals_z.html", null ]
];
